@@ -49,9 +49,9 @@ Categorical$set("public","description","Categorical Probability Distribution.")
 
 Categorical$set("public","mode",function(which = "all"){
   if(which == "all")
-    return(unlist(self$support()$elements)[self$getParameterValue("probs")==max(self$getParameterValue("probs"))])
+    return(unlist(self$support$elements)[self$getParameterValue("probs")==max(self$getParameterValue("probs"))])
   else
-    return(unlist(self$support()$elements)[self$getParameterValue("probs")==max(self$getParameterValue("probs"))][which])
+    return(unlist(self$support$elements)[self$getParameterValue("probs")==max(self$getParameterValue("probs"))][which])
 })
 Categorical$set("public","mean",function(){
   return(NaN)
@@ -111,17 +111,17 @@ Categorical$set("public","initialize",function(..., probs, decorators = NULL, ve
   self$setParameterValue(probs = probs)
 
   pdf <- function(x1){
-    return(self$getParameterValue("probs")[self$support()$elements %in% x1])
+    return(self$getParameterValue("probs")[self$support$elements %in% x1])
   }
   cdf <- function(x1){
-    return(cumsum(self$pdf(self$support()$elements))[self$support()$elements %in% x1])
+    return(cumsum(self$pdf(self$support$elements))[self$support$elements %in% x1])
   }
   quantile <- function(p){
-    cdf = matrix(self$cdf(self$support()$elements), ncol = self$support()$length, nrow = length(p), byrow = T)
-    return(self$support()$elements[apply(cdf >= p, 1, function(x) min(which(x)))])
+    cdf = matrix(self$cdf(self$support$elements), ncol = self$support$length, nrow = length(p), byrow = T)
+    return(self$support$elements[apply(cdf >= p, 1, function(x) min(which(x)))])
   }
   rand <- function(n){
-    return(sample(self$support()$elements, n, TRUE, self$getParameterValue("probs")))
+    return(sample(self$support$elements, n, TRUE, self$getParameterValue("probs")))
   }
 
   super$initialize(decorators = decorators, pdf = pdf, cdf = cdf, quantile = quantile, rand = rand,
