@@ -4,7 +4,7 @@ context("Categorical distribution")
 
 test_that("constructor",{
   expect_equal(Categorical$new()$getParameterValue("probs"),1)
-  expect_equal(Categorical$new()$support(),Set$new(1))
+  expect_equal(Categorical$new()$support,Set$new(1))
   expect_silent(Categorical$new(probs = c(0.1,0.4)))
   expect_silent(Categorical$new("Bapple","Banana",probs = c(0.1,0.4)))
   expect_error(Categorical$new("Bapple","Banana",probs = c(0.1,0.4,0.2)))
@@ -17,9 +17,9 @@ test_that("parameters", {
 })
 
 test_that("properties & traits",{
-  expect_equal(cat$valueSupport(), "discrete")
-  expect_equal(cat$variateForm(), "univariate")
-  expect_equal(cat$symmetry(), "asymmetric")
+  expect_equal(cat$valueSupport, "discrete")
+  expect_equal(cat$variateForm, "univariate")
+  expect_equal(cat$symmetry, "asymmetric")
 })
 
 
