@@ -15,13 +15,13 @@ test_that("parameters", {
 })
 
 test_that("properties & traits",{
-  expect_equal(DiscreteUniform$new()$valueSupport(), "discrete")
-  expect_equal(DiscreteUniform$new()$variateForm(), "univariate")
-  expect_equal(DiscreteUniform$new()$symmetry(), "symmetric")
-  expect_equal(DiscreteUniform$new()$sup(), 1)
-  expect_equal(DiscreteUniform$new()$inf(), 0)
-  expect_equal(DiscreteUniform$new()$dmax(), 1)
-  expect_equal(DiscreteUniform$new()$dmin(), 0)
+  expect_equal(DiscreteUniform$new()$valueSupport, "discrete")
+  expect_equal(DiscreteUniform$new()$variateForm, "univariate")
+  expect_equal(DiscreteUniform$new()$symmetry, "symmetric")
+  expect_equal(DiscreteUniform$new()$sup, 1)
+  expect_equal(DiscreteUniform$new()$inf, 0)
+  expect_equal(DiscreteUniform$new()$dmax, 1)
+  expect_equal(DiscreteUniform$new()$dmin, 0)
 })
 
 du = DiscreteUniform$new()
@@ -35,7 +35,7 @@ test_that("statistics",{
   expect_equal(du$mgf(1),  (1-exp(2))/(2*(1-exp(1))))
   expect_equal(du$cf(1), (1-exp(2i))/(2*(1-exp(1i))))
   expect_equal(du$pgf(1), 1)
-  expect_equal(du$mode(),du$inf():du$sup())
+  expect_equal(du$mode(),du$inf:du$sup)
   expect_equal(du$mode(2),1)
   expect_equal(du$pdf(1), 1/2)
   expect_equal(du$cdf(1), 1)
