@@ -14,15 +14,15 @@ test_that("parameterisation", {
 })
 
 test_that("properties & traits", {
-  expect_equal(FDistribution$new()$valueSupport(), "continuous")
-  expect_equal(FDistribution$new()$variateForm(), "univariate")
-  expect_equal(FDistribution$new()$symmetry(), "asymmetric")
-  expect_equal(FDistribution$new()$sup(), Inf)
-  expect_equal(FDistribution$new()$inf(), 0)
-  expect_equal(FDistribution$new()$dmax(), Inf)
-  expect_equal(FDistribution$new()$dmin(), 0)
-  expect_equal(FDistribution$new(df1 = 5, df2 = 5)$dmax(), Inf)
-  expect_equal(FDistribution$new(df1 = 5, df2 = 5)$dmin(), .Machine$double.eps)
+  expect_equal(FDistribution$new()$valueSupport, "continuous")
+  expect_equal(FDistribution$new()$variateForm, "univariate")
+  expect_equal(FDistribution$new()$symmetry, "asymmetric")
+  expect_equal(FDistribution$new()$sup, Inf)
+  expect_equal(FDistribution$new()$inf, 0)
+  expect_equal(FDistribution$new()$dmax, Inf)
+  expect_equal(FDistribution$new()$dmin, 0)
+  expect_equal(FDistribution$new(df1 = 5, df2 = 5)$dmax, Inf)
+  expect_equal(FDistribution$new(df1 = 5, df2 = 5)$dmin, .Machine$double.eps)
 })
 
 f1 <- FDistribution$new(df1 = 4)
