@@ -3,13 +3,13 @@ library(testthat)
 context("Logarithmic distribution")
 
 test_that("properties & traits",{
-  expect_equal(Logarithmic$new()$valueSupport(), "discrete")
-  expect_equal(Logarithmic$new()$variateForm(), "univariate")
-  expect_equal(Logarithmic$new()$symmetry(), "asymmetric")
-  expect_equal(Logarithmic$new()$sup(), Inf)
-  expect_equal(Logarithmic$new()$inf(), 1)
-  expect_equal(Logarithmic$new()$dmax(), Inf)
-  expect_equal(Logarithmic$new()$dmin(), 1)
+  expect_equal(Logarithmic$new()$valueSupport, "discrete")
+  expect_equal(Logarithmic$new()$variateForm, "univariate")
+  expect_equal(Logarithmic$new()$symmetry, "asymmetric")
+  expect_equal(Logarithmic$new()$sup, Inf)
+  expect_equal(Logarithmic$new()$inf, 1)
+  expect_equal(Logarithmic$new()$dmax, Inf)
+  expect_equal(Logarithmic$new()$dmin, 1)
 })
 
 l = Logarithmic$new()
