@@ -24,15 +24,15 @@ test_that("parameters", {
 })
 
 test_that("properties & traits",{
-  expect_equal(Triangular$new()$valueSupport(), "continuous")
-  expect_equal(Triangular$new()$variateForm(), "univariate")
-  expect_equal(Triangular$new(symmetric = T)$symmetry(), "symmetric")
-  expect_equal(Triangular$new(symmetric = F)$symmetry(), "symmetric")
-  expect_equal(Triangular$new(symmetric = F, mode = 0.2)$symmetry(), "asymmetric")
-  expect_equal(Triangular$new()$sup(), 1)
-  expect_equal(Triangular$new()$inf(), 0)
-  expect_equal(Triangular$new()$dmax(), 1)
-  expect_equal(Triangular$new()$dmin(), 0)
+  expect_equal(Triangular$new()$valueSupport, "continuous")
+  expect_equal(Triangular$new()$variateForm, "univariate")
+  expect_equal(Triangular$new(symmetric = T)$symmetry, "symmetric")
+  expect_equal(Triangular$new(symmetric = F)$symmetry, "symmetric")
+  expect_equal(Triangular$new(symmetric = F, mode = 0.2)$symmetry, "asymmetric")
+  expect_equal(Triangular$new()$sup, 1)
+  expect_equal(Triangular$new()$inf, 0)
+  expect_equal(Triangular$new()$dmax, 1)
+  expect_equal(Triangular$new()$dmin, 0)
 })
 
 t = Triangular$new()
