@@ -8,7 +8,7 @@ test_that("var & squared-norm",{
 })
 
 test_that("support",{
-  expect_equal(quart$support()$strprint(), Interval$new(-1,1)$strprint())
+  expect_equal(quart$support$strprint(), Interval$new(-1,1)$strprint())
 })
 
 test_that("d/p/q/r",{
