@@ -16,26 +16,32 @@ test_that("parameters",{
 })
 
 test_that("wrapped models",{
-  vec = VectorDistribution$new(list(Binomial$new(),Normal$new()))
-  expect_equal(vec$wrappedModels("Binom"),Binomial$new())
-  expect_equal(vec$wrappedModels(c("Binom","Norm")), list(Binom=Binomial$new(),Norm=Normal$new()))
-  expect_equal(vec$wrappedModels("asds"),list(Binom=Binomial$new(),Norm=Normal$new()))
+  mix = MixtureDistribution$new(list(Binomial$new(),Normal$new()))
+  expect_equal(mix$wrappedModels("Binom"),Binomial$new())
+  expect_equal(mix$wrappedModels(), list(Binom = Binomial$new(),Norm = Normal$new()))
+  expect_equal(mix$wrappedModels("sdsd"), list(Binom = Binomial$new(),Norm = Normal$new()))
+  expect_equal(mix$wrappedModels(c("Binom","Norm")), list(Binom=Binomial$new(),Norm=Normal$new()))
 })
 
 test_that("unique parameters",{
   vec = VectorDistribution$new(list(Normal$new(),Normal$new()))
-  expect_silent(vec$getParameterValue("Norm1_mean"))
-  expect_silent(vec$getParameterValue("Norm2_mean"))
-  expect_equal(vec$setParameterValue(Norm1_var = 2)$getParameterValue("Norm1_prec"),1/2)
-  expect_equal(vec$setParameterValue(Norm2_sd = 2)$getParameterValue("Norm2_var"),4)
+  expect_message(expect_null(vec$getParameterValue("Norm1_mean")))
 })
 
 
 test_that("wrap a wrapper",{
-  expect_silent(VectorDistribution$new(list(ProductDistribution$new(list(MixtureDistribution$new(list(Exponential$new(),
-                                   huberize(truncate(Normal$new(),lower = -10, upper = 10),-5,5))),
-                                   VectorDistribution$new(distribution = Gompertz,params=list(list(shape = 2, scale = 4),list(shape = 1, scale = 5))))),
-                                  Binomial$new())))
+  expect_silent(VectorDistribution$new(
+    list(
+      ProductDistribution$new(list(
+        MixtureDistribution$new(list(
+          Exponential$new(),
+          huberize(truncate(Normal$new(),lower = -10, upper = 10),-5,5)
+          )),
+        VectorDistribution$new(distribution = "Gompertz", params=list(list(shape = 2, scale = 4),
+                                 list(shape = 1, scale = 5)))
+        )),
+      Binomial$new()
+      )))
   x = ProductDistribution$new(list(MixtureDistribution$new(list(Exponential$new(),
                                                                   huberize(truncate(Normal$new(),lower = -10, upper = 10),-5,5))),
                                                                     Binomial$new()))
